OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Sala",
    "Unknown" : "Desconocido",
    "Required" : "Obligatorio",
    "Optional" : "Opcional",
    "Please create a calendar first." : "Por favor, primero crea un calendario",
    "New event" : "Nuevo evento",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repetición",
    "When shared show full event" : "Mostrar el evento completo al compartir",
    "When shared show only busy" : "Mostrar solo cuándo estoy ocupado al compartir",
    "When shared hide this event" : "Ocultar este evento al compartir",
    "Cancelled" : "Cancelado",
    "Please add a title!" : "Por favor agrega un título!",
    "Please select a calendar!" : "Por favor selecciona un calendario!",
    "None" : "Ninguno",
    "Every day" : "Cada día",
    "Every week" : "Cada semana",
    "Every month" : "Cada mes",
    "Every year" : "Cada año",
    "never" : "nunca",
    "after" : "después",
    "At time of event" : "A la hora del evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizado",
    "Audio" : "Audio",
    "E Mail" : "Correo electrónico",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "días",
    "week" : "semana",
    "before" : "antes",
    "start" : "inicia",
    "end" : "termina",
    "Editing reminders of unknown type not supported." : "No es compatible modificar avisos de tipo desconocido",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Se ha importado exitosamente",
    "Partially imported, 1 failure" : "Parcialmente importado, 1 falla",
    "Partially imported, {n} failures" : "Parcialmente importado, {n} fallas",
    "Audio alarm" : "Alarma de audio",
    "E-Mail" : "Correo electrónico",
    "{type} {time} before the event starts" : "{type} {time} antes de iniciar el evento",
    "{type} {time} before the event ends" : "{type} {time} antes de terminar el evento",
    "{type} {time} after the event starts" : "{type} {time} después de iniciar el evento",
    "{type} {time} after the event ends" : "{type} {time} después de terminar el evento",
    "{type} at the event's start" : "{type} al inicio del evento",
    "{type} at the event's end" : "{type} al final del evento",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Title of the Event" : "Título del evento",
    "starts" : "Comienzan",
    "ends" : "Terminan",
    "All day Event" : "Evento de todo el día",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "More ..." : "Más...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Close" : "Cerrar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Export" : "Exportar",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor, ponte en contacto con el administrador y pidele desactivar la opción de configuración \"asset-pipeline.enabled\".",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Today" : "Hoy",
    "Share Calendar" : "Compartir calendario",
    "Shared" : "Compartido",
    "More" : "Más",
    "Edit" : "Editar",
    "Download" : "Descargar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "can edit" : "puede editar",
    "group" : "grupo",
    "New Calendar" : "Nuevo calendario",
    "Subscriptions" : "Suscripciones",
    "New Subscription" : "Nueva suscripción",
    "Url" : "Url",
    "Edit event" : "Editar evento",
    "Delete Event" : "Borrar evento",
    "Save Event" : "GUardar evento",
    "Time" : "Hora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "todos los tiempos",
    "Add" : "Añadir",
    "E-Mail address of attendee" : "Dirección de correo electrónico de asistentes",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor agrega tu dirección de correo electrónico en los ajustes personales con el fin de agregar asistentes",
    "from" : "de",
    "to" : "hasta",
    "This event's repeating rule is not supported yet." : "La regla de repetición de este evento no se admite todavía.",
    "Support for advanced rules will be added with subsequent updates." : "El soporte para reglas avanzadas se añadirá con actualizaciones posteriores.",
    "Reset repeating rule" : "Reesablece la regla de repetción",
    "Repeat every ..." : "Repite cada ...",
    "Import Calendars" : "Importar Calendarios",
    "Import canceled" : "Importación cancelada",
    "Analyzing calendar" : "Analizando calendario",
    "The file contains objects incompatible with the selected calendar" : "El archivo contiene objetos incompatibles con el calendario seleccionado",
    "New calendar" : "Nuevo calendario",
    "Settings" : "Ajustes",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "No hay Calendarios para importar",
    "Primary CalDAV address" : "Dirección primaria de CalDAV",
    "iOS/OS X CalDAV address" : "Dirección CalDAV de iOS/OS X"
},
"nplurals=2; plural=(n != 1);");
